You are viewing a plain text version of this content. The canonical link for it is here.
Posted to reviews@iotdb.apache.org by GitBox <gi...@apache.org> on 2019/12/03 05:42:57 UTC

[GitHub] [incubator-iotdb] liutaohua opened a new pull request #614: [IOTDB-306] new reader with ChunkMetaData for aggregateFunction

liutaohua opened a new pull request #614: [IOTDB-306] new reader with ChunkMetaData for aggregateFunction
URL: https://github.com/apache/incubator-iotdb/pull/614
 
 
   In the old interface, data filtering could not be use the chunk level, which I think may not have been considered in the previous design. Now the IAggregateReader interface has been added `hasNextChunk`  `nextChunkMeta` `hasNextPageInCurrentChunk`.
   
   The advantage of this is that Statistics can be used in the AggrFunction, there is no need to read page
   
   This some test, **i restart the server after each kind of test**:
   
   1. 10,000 data without chunkMeta and unseq
   IoTDB> `select count(*) from root`
   It costs 0.290s
   IoTDB> `select first_value(*) from root`
   It costs 0.657s
   IoTDB> `select last_value(*) from root`
   It costs 0.156s
   IoTDB> `select sum(*) from root`
   It costs 0.224s
   IoTDB> `select avg(*) from root`
   It costs 0.272s
   IoTDB> `select max_time(*) from root`
   It costs 0.117s
   
   1. 10,000 data with chunkMeta but without unseq
   IoTDB>  `select count(*) from root`
   It costs 0.006s
   IoTDB> `select first_value(*) from root`
   It costs 0.006s
   IoTDB> `select sum(*) from root`
   It costs 0.005s
   IoTDB> `select avg(*) from root`
   It costs 0.006s
   IoTDB> `select max_time(*) from root`
   It costs 0.004s
   

----------------------------------------------------------------
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services